@@ -1,11 +1,13 @@
 from abc import ABC
 from typing import TYPE_CHECKING
 
+from bclib.exception import ShortCircuitErr
+
 if TYPE_CHECKING:
     from .. import dispatcher
 
 from bclib.db_manager import SqlDb, SQLiteDb, MongoDb, RabbitConnection, RESTfulConnection
-from bclib.utility import DictEx
+from bclib.utility import DictEx, HttpStatusCodes
 
 
 class Context(ABC):
@@ -32,3 +34,17 @@ class Context(ABC):
 
     def open_rabbit_connection(self, key: str) -> RabbitConnection:
         return self.dispatcher.db_manager.open_rabbit_connection(key)
+
+    def generate_error_responce(self, exception: Exception) -> dict:
+        """Generate error responce from process result"""
+        return self._generate_error_object(exception)
+
+    def _generate_error_object(self, exception: Exception) -> dict:
+        """Generate error object from exception object"""
+        error_code = None
+        if isinstance(exception, ShortCircuitErr):
+            self.status_code = exception.status_code
+            error_code = exception.error_code
+        else:
+            self.status_code = HttpStatusCodes.INTERNAL_SERVER_ERROR
+        return {"errorCode": error_code, "errorMessage": str(exception)}
