@@ -1,5 +1,5 @@
 import json
-from typing import Any, TYPE_CHECKING
+from typing import TYPE_CHECKING
 
 from bclib.utility import HttpMimeTypes
 from bclib.listener.http_listener import HttpBaseDataName, HttpBaseDataType
@@ -16,7 +16,12 @@ class JsonBaseRequestContext(RequestContext):
         super().__init__(cms_object, dispatcher)
         self.mime = HttpMimeTypes.JSON
 
-    def generate_responce(self, result: Any) -> dict:
+    def generate_error_responce(self,  exception: Exception) -> dict:
+        """Generate error responce from process result"""
+        error_object = self._generate_error_object(exception)
+        return self.generate_responce(error_object)
+
+    def generate_responce(self, result: dict) -> dict:
         """Generate responce from process result"""
 
         ret_val = super().generate_responce(result)
