@@ -1,5 +1,5 @@
-from abc import abstractmethod
 from typing import Any, TYPE_CHECKING
+
 from bclib.listener.http_listener import HttpBaseDataName, HttpBaseDataType
 from bclib.utility import DictEx, HttpStatusCodes, HttpMimeTypes, ResponseTypes
 from ..context.context import Context
@@ -32,7 +32,12 @@ class RequestContext(Context):
         else:
             self.__headers[key].append(value)
 
-    @abstractmethod
+    def generate_error_responce(self, exception: Exception) -> dict:
+        """Generate error responce from process result"""
+        error_object = self._generate_error_object(exception)
+        content = f"{error_object['errorMessage']} (Error Code: {error_object['errorCode']})"
+        return self.generate_responce(content)
+
     def generate_responce(self, result: Any) -> dict:
         """Generate responce from process result"""
 
