@@ -3,36 +3,21 @@ import asyncio
 from abc import ABC, abstractmethod
 from typing import Callable, Any
 from functools import wraps
+
 from bclib.cache import create_chaching
 from bclib.listener import RabbitBusListener, MessageType
-from bclib.predicate import Predicate, InList, Equal, Url, Between, NotEqual, GreaterThan, LessThan, LessThanEqual, GreaterThanEqual, Match, HasValue
-from bclib.context import SourceContext, SourceMemberContext, WebContext, Context, RESTfulContext, RabbitContext, SocketContext, ServerSourceContext, ServerSourceMemberContext
+from bclib.predicate import Predicate, InList, Equal, Url, Between, NotEqual, GreaterThan, LessThan, LessThanEqual, GreaterThanEqual, Match, HasValue, Callback
+from bclib.context import ClientSourceContext, ClientSourceMemberContext, WebContext, Context, RESTfulContext, RabbitContext, SocketContext, ServerSourceContext, ServerSourceMemberContext
 from bclib.db_manager import DbManager
 from bclib.utility import DictEx
 from ..dispatcher.callback_info import CallbackInfo
-from bclib import __version__
+from bclib.exception import HandlerNotFoundErr
 
 
 class Dispatcher(ABC):
     """Base class for dispaching request"""
 
     def __init__(self, options: dict = None):
-        print(f'''
-______           _                          _____    _            
-| ___ \         (_)                        |  ___|  | |           
-| |_/ / __ _ ___ _ ___  ___ ___  _ __ ___  | |__  __| | __ _  ___ 
-| ___ \/ _` / __| / __|/ __/ _ \| '__/ _ \ |  __|/ _` |/ _` |/ _ \\
-| |_/ / (_| \__ \ \__ \ (_| (_) | | |  __/ | |__| (_| | (_| |  __/
-\____/ \__,_|___/_|___/\___\___/|_|  \___| \____/\__,_|\__, |\___|
-                                                        __/ |     
-                                                       |___/      
-                                     
-***********************************
-Welcome To BasisCore Ecosystem
-follow us on https://BasisCore.com/
-bclib Version : {__version__}
-***********************************
-''')
         self.options = DictEx(options)
         self.__look_up: 'dict[str, list[CallbackInfo]]' = dict()
         cache_options = self.options.cache if "cache" in self.options else None
@@ -47,51 +32,51 @@ bclib Version : {__version__}
     def socket_action(self, * predicates: (Predicate)):
         """Decorator for determine Socket action"""
 
-        def _decorator(socket_action: 'Callable[[SocketContext], list]'):
-            @wraps(socket_action)
-            def _wrapper(context: SocketContext):
-                socket_action(context)
+        def _decorator(socket_action_handler: 'Callable[[SocketContext],None]'):
+            @wraps(socket_action_handler)
+            def wrapper(context: SocketContext):
+                socket_action_handler(context)
                 return True
             self._get_context_lookup(SocketContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], wrapper))
+            return socket_action_handler
         return _decorator
 
     def restful_action(self, * predicates: (Predicate)):
         """Decorator for determine RESTful action"""
 
-        def _decorator(restful_action: 'Callable[[RESTfulContext], list]'):
-            @wraps(restful_action)
-            def _wrapper(context: RESTfulContext):
-                return restful_action(context)
+        def _decorator(restful_action_handler: 'Callable[[RESTfulContext], dict]'):
+            @wraps(restful_action_handler)
+            def wrapper(context: RESTfulContext):
+                return context.generate_responce(restful_action_handler(context))
             self._get_context_lookup(RESTfulContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], wrapper))
+            return restful_action_handler
         return _decorator
 
     def web_action(self, * predicates: (Predicate)):
         """Decorator for determine legacy web request action"""
 
-        def _decorator(web_action: 'Callable[[WebContext], list]'):
-            @wraps(web_action)
-            def _wrapper(context: WebContext):
-                return web_action(context)
+        def _decorator(web_action_handler: 'Callable[[WebContext], str]'):
+            @wraps(web_action_handler)
+            def wrapper(context: WebContext):
+                return context.generate_responce(web_action_handler(context))
             self._get_context_lookup(WebContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], wrapper))
+            return web_action_handler
         return _decorator
 
-    def source_action(self, *predicates: (Predicate)):
+    def client_source_action(self, *predicates: (Predicate)):
         """Decorator for determine source action"""
 
-        def _decorator(source_action: 'Callable[[SourceContext], list]'):
-            @wraps(source_action)
-            def _wrapper(context: SourceContext):
-                data = source_action(context)
+        def _decorator(client_source_action_handler: 'Callable[[ClientSourceContext], Any]'):
+            @wraps(client_source_action_handler)
+            def wrapper(context: ClientSourceContext):
+                data = client_source_action_handler(context)
                 result_set = list()
                 if data is not None:
                     for member in context.command.member:
-                        member_context = SourceMemberContext(
+                        member_context = ClientSourceMemberContext(
                             context, data, member)
                         dispath_result = self.dispatch(member_context)
                         result = {
@@ -99,7 +84,7 @@ bclib Version : {__version__}
                                 "tableName": member_context.table_name,
                                 "keyFieldName": member_context.key_field_name,
                                 "statusFieldName": member_context.status_field_name,
-                                "mergeType": member_context.merge_type.value[0]
+                                "mergeType": member_context.merge_type.value
                             },
                             "data": dispath_result
                         }
@@ -110,33 +95,28 @@ bclib Version : {__version__}
                     },
                     "sources": result_set
                 }
-                return ret_val
-            self._get_context_lookup(SourceContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                return context.generate_responce(ret_val)
+            self._get_context_lookup(ClientSourceContext.__name__)\
+                .append(CallbackInfo([*predicates], wrapper))
+            return client_source_action_handler
         return _decorator
 
-    def source_member_action(self, *predicates: (Predicate)):
+    def client_source_member_action(self, *predicates: (Predicate)):
         """Decorator for determine source member action methode"""
 
-        def _decorator(function: 'Callable[[SourceMemberContext], list]'):
-
-            @wraps(function)
-            def _wrapper(context: SourceMemberContext):
-                return function(context)
-
-            self._get_context_lookup(SourceMemberContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+        def _decorator(client_source_member_handler: 'Callable[[ClientSourceMemberContext], Any]'):
+            self._get_context_lookup(ClientSourceMemberContext.__name__)\
+                .append(CallbackInfo([*predicates], client_source_member_handler))
+            return client_source_member_handler
         return _decorator
 
     def server_source_action(self, *predicates: (Predicate)):
         """Decorator for determine source action"""
 
-        def _decorator(source_action: 'Callable[[ServerSourceContext], list]'):
-            @wraps(source_action)
-            def _wrapper(context: ServerSourceContext):
-                data = source_action(context)
+        def _decorator(server_source_action_handler: 'Callable[[ServerSourceContext], Any]'):
+            @wraps(server_source_action_handler)
+            def wrapper(context: ServerSourceContext):
+                data = server_source_action_handler(context)
                 result_set = list()
                 if data is not None:
                     for member in context.command.member:
@@ -148,7 +128,7 @@ bclib Version : {__version__}
                                 "tableName": member_context.table_name,
                                 "keyFieldName": member_context.key_field_name,
                                 "statusFieldName": member_context.status_field_name,
-                                "mergeType": member_context.merge_type.value[0]
+                                "mergeType": member_context.merge_type.value
                             },
                             "data": dispath_result
                         }
@@ -159,37 +139,32 @@ bclib Version : {__version__}
                     },
                     "sources": result_set
                 }
-                return ret_val
+                return context.generate_responce(ret_val)
             self._get_context_lookup(ServerSourceContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], wrapper))
+            return server_source_action_handler
         return _decorator
 
     def server_source_member_action(self, *predicates: (Predicate)):
         """Decorator for determine server source member action methode"""
 
-        def _decorator(function: 'Callable[[ServerSourceMemberContext], list]'):
-
-            @wraps(function)
-            def _wrapper(context: ServerSourceMemberContext):
-                return function(context)
-
+        def _decorator(server_source_member_action_handler: 'Callable[[ServerSourceMemberContext], Any]'):
             self._get_context_lookup(ServerSourceMemberContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], server_source_member_action_handler))
+            return server_source_member_action_handler
         return _decorator
 
     def rabbit_action(self, * predicates: (Predicate)):
         """Decorator for determine rabbit-mq message request action"""
 
-        def _decorator(web_action: 'Callable[[RabbitContext], list]'):
-            @wraps(web_action)
-            def _wrapper(context: RabbitContext):
-                web_action(context)
+        def _decorator(rabbit_action_handler: 'Callable[[RabbitContext], None]'):
+            @wraps(rabbit_action_handler)
+            def wrapper(context: RabbitContext):
+                rabbit_action_handler(context)
                 return True
             self._get_context_lookup(RabbitContext.__name__)\
-                .append(CallbackInfo([*predicates], _wrapper))
-            return _wrapper
+                .append(CallbackInfo([*predicates], wrapper))
+            return wrapper
         return _decorator
 
     def _get_context_lookup(self, key: str) -> 'list[CallbackInfo]':
@@ -208,13 +183,23 @@ bclib Version : {__version__}
 
         result: Any = None
         name = type(context).__name__
-        items = self._get_context_lookup(name)
-        for item in items:
-            result = item.try_execute(context)
-            if result is not None:
-                break
+        try:
+            items = self._get_context_lookup(name)
+            for item in items:
+                result = item.try_execute(context)
+                if result is not None:
+                    break
+            else:
+                result = context.generate_error_responce(
+                    HandlerNotFoundErr(name))
+        except Exception as ex:
+            result = context.generate_error_responce(ex)
         return result
 
+    def initialize_task(self, loop: asyncio.AbstractEventLoop):
+        for dispacher in self.__rabbit_dispatcher:
+            dispacher.initialize_task(loop)
+
     def listening(self):
         for dispacher in self.__rabbit_dispatcher:
             dispacher.start_listening()
@@ -226,7 +211,7 @@ bclib Version : {__version__}
         return loop.run_in_executor(None, callback, *args)
 
     @abstractmethod
-    def send_message(self, message: MessageType) -> bool:
+    async def send_message(self, message: MessageType) -> bool:
         """Send message to endpoint"""
 
     def cache(self, seconds: int = 0, key: str = None):
@@ -299,3 +284,9 @@ bclib Version : {__version__}
         """Create has value cheking predicate"""
 
         return HasValue(expression)
+
+    @staticmethod
+    def callback(callback: 'Callable[[Context],bool]') -> Predicate:
+        """Create Callback cheking predicate"""
+
+        return Callback(callback)
